@@ -20,18 +20,25 @@
 
 #include "gimage.h"
 #include "tools.h"
-#include "procedural_db.h"
 
+extern Channel *fuzzy_mask;
 
 /*  fuzzy select functions  */
-Tool *        tools_new_fuzzy_select      (void);
-void          tools_free_fuzzy_select     (Tool *);
-
+Tool    * tools_new_fuzzy_select  (void);
+void      tools_free_fuzzy_select (Tool *tool);
 
 /*  functions  */
-Channel *     find_contiguous_region      (GImage *, GimpDrawable *, int, int, int, int, int);
+Channel * find_contiguous_region  (GimpImage    *gimage,
+				   GimpDrawable *drawable,
+				   gboolean      antialias,
+				   gint          threshold,
+				   gint          x,
+				   gint          y,
+				   gboolean      sample_merged);
+void      fuzzy_select            (GimpImage    *gimage,
+				   GimpDrawable *drawable,
+				   gint          op,
+				   gboolean      feather,
+				   gdouble       feather_radius);
 
-/*  Procedure definition and marshalling function  */
-extern ProcRecord fuzzy_select_proc;
-
-#endif  /*  __FUZZY_SELECT_H__  */
+#endif  /* __FUZZY_SELECT_H__ */
